@@ -1,15 +1,15 @@
 use luau_src::vm as raw;
 
 #[repr(transparent)]
-pub struct Lua(pub *mut raw::lua_State);
+pub struct Luau(pub *mut raw::lua_State);
 
-impl Drop for Lua {
+impl Drop for Luau {
 	fn drop(&mut self) {
 		unsafe { raw::lua_close(self.0) }
 	}
 }
 
-impl Default for Lua {
+impl Default for Luau {
 	fn default() -> Self {
 		Self::new()
 	}
